Learn R Programming

pdynmc (version 0.9.13)

AH81: Estimator of Anderson and Hsiao (1981).

Description

AH81 computes closed form estimator for lag parameter of linear dynamic panel data model based on Anderson & Hsiao (1981) (AH81) estimator.

Usage

AH81(dat, varname.i, varname.t, varname.y, eq8.2 = TRUE)

Value

An object of class `numeric` that contains the coefficient estimate for the lag parameter according to the two roots of the quadratic equation.

Arguments

dat

A dataset.

varname.i

The name of the cross-section identifier.

varname.t

The name of the time-series identifier.

varname.y

A character string denoting the name of the dependent variable in the dataset.

eq8.2

A logical variable indicating whether the estimation function is based on Equation (8.2) of Anderson and Hsiao (1981); otherwise Equation (8.1) is employed (defaults to `TRUE`).

Author

Joachim Schnurbus, Markus Fritsch

Details

The function estimates a linear dynamic panel data model of the form $$y_{i,t} = y_{i,t-1} \rho_1 + a_i + \varepsilon_{i,t}$$ where \(y_{i,t-1}\) is the lagged dependent variable, \(\rho_1\) is the lag parameter, \(a_i\) is an unobserved individual specific effect, and \(\varepsilon_{i,t}\) is an idiosyncratic remainder component. The model structure accounts for unobserved individual specific heterogeneity and dynamics. Note that more general lag structures and further covariates are beyond the scope of the current implementation in pdynmc.

More details on the AH81 estimator and its properties are provided in AndHsi1981;textualpdynmc and AndHsi1982;textualpdynmc.

References

Examples

Run this code
## Load data
data(cigDemand, package = "pdynmc")
dat <- cigDemand

## Code example
m1 <- AH81(dat = dat, varname.i = "state", varname.t = "year", varname.y = "packpc")


Run the code above in your browser using DataLab