Learn R Programming

pdynmc (version 0.9.13)

NLIV: Nonlinear Instrumental Variables Estimator - T-Version (NLIV).

Description

NLIV Computes closed form solution for lag parameter of linear dynamic panel data model based on instrumental variables (IV) estimator employing nonlinear moment conditions.

Usage

NLIV(dat, varname.i, varname.t, varname.y, trueAR = NULL)

Value

An object of class `numeric` that contains the coefficient estimate for the lag parameter according to the two roots of the quadratic equation.

Arguments

dat

A dataset.

varname.i

The name of the cross-section identifier.

varname.t

The name of the time-series identifier.

varname.y

A character string denoting the name of the dependent variable in the dataset.

trueAR

A logical variable indicating whether the true autoregressive parameter is known (defaults to `NULL`). The parameter is used to compute the terms `A`, `B`, and `C` that can be employed to rewrite the estimating equation. For details, see FriPuaSch2024;textualpdynmc.

Author

Joachim Schnurbus, Markus Fritsch

Details

The function estimates a linear dynamic panel data model of the form $$y_{i,t} = y_{i,t-1} \rho_1 + a_i + \varepsilon_{i,t}$$ where \(y_{i,t-1}\) is the lagged dependent variable, \(\rho_1\) is the lag parameter, \(a_i\) is an unobserved individual specific effect, and \(\varepsilon_{i,t}\) is an idiosyncratic remainder component. The model structure accounts for unobserved individual specific heterogeneity and dynamics. Note that more general lag structures and further covariates are beyond the scope of the current implementation in pdynmc.

The nonlinear IV estimator employs the original version of the nonlinear moment conditions of AhnSch1995;textualpdynmc. More details on the implementation, the properties of the estimator, and how to account for predetermined covariates are provided in FriPuaSch2024;textualpdynmc.

References

Examples

Run this code
## Load data
data(cigDemand, package = "pdynmc")
dat <- cigDemand

## Code example
m1 <- NLIV(dat = dat, varname.i = "state", varname.t = "year", varname.y = "packpc")


Run the code above in your browser using DataLab