The function estimates a linear dynamic panel data model of the form
$$y_{i,t} = y_{i,t-1} \rho_1 + a_i + \varepsilon_{i,t}$$
where \(y_{i,t-1}\) is the lagged dependent variable, \(\rho_1\) is
the lag parameter, \(a_i\) is an unobserved individual specific effect,
and \(\varepsilon_{i,t}\) is an idiosyncratic remainder component. The
model structure accounts for unobserved individual specific heterogeneity
and dynamics. Note that more general lag structures and further covariates
are beyond the scope of the current implementation in pdynmc.
The nonlinear IV estimator employs the original version of the nonlinear
moment conditions of AhnSch1995;textualpdynmc.
More details on the implementation, the properties of the estimator, and
how to account for predetermined covariates are provided in
FriPuaSch2024;textualpdynmc.